# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataErrorDetail(Model):
    """ODataErrorDetail.

    :param error_code:
    :type error_code: str
    :param message:
    :type message: str
    :param target:
    :type target: str
    """

    _attribute_map = {
        'error_code': {'key': 'errorCode', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'target': {'key': 'target', 'type': 'str'},
    }

    def __init__(self, *, error_code: str=None, message: str=None, target: str=None, **kwargs) -> None:
        super(ODataErrorDetail, self).__init__(**kwargs)
        self.error_code = error_code
        self.message = message
        self.target = target
