# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LogMessage(Model):
    """LogMessage.

    :param location:
    :type location: ~dynamics.customerinsights.api.models.SourceLocation
    :param message:
    :type message: str
    """

    _attribute_map = {
        'location': {'key': 'location', 'type': 'SourceLocation'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, *, location=None, message: str=None, **kwargs) -> None:
        super(LogMessage, self).__init__(**kwargs)
        self.location = location
        self.message = message
