# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureLinkedEntity(Model):
    """Represents the base linked entity.

    :param kind: Possible values include: 'base', 'join', 'scalar'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param entity: Gets the name of the entity.
    :type entity: str
    :param alias: Gets the alias of the entity.
    :type alias: str
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'entity': {'key': 'entity', 'type': 'str'},
        'alias': {'key': 'alias', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MeasureLinkedEntity, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.entity = kwargs.get('entity', None)
        self.alias = kwargs.get('alias', None)
