# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class QueryMetadata(Model):
    """QueryMetadata.

    :param query_id:
    :type query_id: str
    :param query_name:
    :type query_name: str
    :param query_group_id:
    :type query_group_id: str
    :param entity_name:
    :type entity_name: str
    :param load_enabled:
    :type load_enabled: bool
    """

    _attribute_map = {
        'query_id': {'key': 'queryId', 'type': 'str'},
        'query_name': {'key': 'queryName', 'type': 'str'},
        'query_group_id': {'key': 'queryGroupId', 'type': 'str'},
        'entity_name': {'key': 'entityName', 'type': 'str'},
        'load_enabled': {'key': 'loadEnabled', 'type': 'bool'},
    }

    def __init__(self, *, query_id: str=None, query_name: str=None, query_group_id: str=None, entity_name: str=None, load_enabled: bool=None, **kwargs) -> None:
        super(QueryMetadata, self).__init__(**kwargs)
        self.query_id = query_id
        self.query_name = query_name
        self.query_group_id = query_group_id
        self.entity_name = entity_name
        self.load_enabled = load_enabled
