# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentationPublishStats(Model):
    """SegmentationPublishStats.

    :param job_status: Possible values include: 'None', 'Queued', 'Running',
     'CompletedSuccess', 'CompletedFailure', 'Cancelled', 'Interrupted',
     'NotQualified'
    :type job_status: str or ~dynamics.customerinsights.api.models.enum
    :param evaluation_date:
    :type evaluation_date: datetime
    :param entity_count:
    :type entity_count: long
    :param error:
    :type error: ~dynamics.customerinsights.api.models.StringInfo
    :param last_successful_run_id:
    :type last_successful_run_id: str
    """

    _attribute_map = {
        'job_status': {'key': 'jobStatus', 'type': 'str'},
        'evaluation_date': {'key': 'evaluationDate', 'type': 'iso-8601'},
        'entity_count': {'key': 'entityCount', 'type': 'long'},
        'error': {'key': 'error', 'type': 'StringInfo'},
        'last_successful_run_id': {'key': 'lastSuccessfulRunId', 'type': 'str'},
    }

    def __init__(self, *, job_status=None, evaluation_date=None, entity_count: int=None, error=None, last_successful_run_id: str=None, **kwargs) -> None:
        super(SegmentationPublishStats, self).__init__(**kwargs)
        self.job_status = job_status
        self.evaluation_date = evaluation_date
        self.entity_count = entity_count
        self.error = error
        self.last_successful_run_id = last_successful_run_id
