# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReferenceModel(Model):
    """ReferenceModel.

    :param id:
    :type id: str
    :param location:
    :type location: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'location': {'key': 'location', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, location: str=None, **kwargs) -> None:
        super(ReferenceModel, self).__init__(**kwargs)
        self.id = id
        self.location = location
