# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchyDefinition(Model):
    """Represents a Hierarchy entity used to define a B2B segment/measure.

    :param hierarchy_entity_name: Gets the Hierarchy entity fully qualified
     name.
    :type hierarchy_entity_name: str
    :param source_attribute_name: Gets the Hierarchy entity Source attribute
     name.
    :type source_attribute_name: str
    :param destination_attribute_name: Gets the Hierarchy entity Destination
     attribute name.
    :type destination_attribute_name: str
    """

    _attribute_map = {
        'hierarchy_entity_name': {'key': 'hierarchyEntityName', 'type': 'str'},
        'source_attribute_name': {'key': 'sourceAttributeName', 'type': 'str'},
        'destination_attribute_name': {'key': 'destinationAttributeName', 'type': 'str'},
    }

    def __init__(self, *, hierarchy_entity_name: str=None, source_attribute_name: str=None, destination_attribute_name: str=None, **kwargs) -> None:
        super(HierarchyDefinition, self).__init__(**kwargs)
        self.hierarchy_entity_name = hierarchy_entity_name
        self.source_attribute_name = source_attribute_name
        self.destination_attribute_name = destination_attribute_name
