# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Notifications(Model):
    """Settings to track notifications that users have viewed and dismissed.

    :param history:
    :type history: ~dynamics.customerinsights.api.models.History
    """

    _attribute_map = {
        'history': {'key': 'history', 'type': 'History'},
    }

    def __init__(self, **kwargs):
        super(Notifications, self).__init__(**kwargs)
        self.history = kwargs.get('history', None)
