# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivitySourceEntityInfo(Model):
    """Collection of the entity name and other info of the source activity entity
    ingested by user.

    :param entity_name: Gets the qualified entity name of the activity source
     entity.
    :type entity_name: str
    """

    _attribute_map = {
        'entity_name': {'key': 'entityName', 'type': 'str'},
    }

    def __init__(self, *, entity_name: str=None, **kwargs) -> None:
        super(ActivitySourceEntityInfo, self).__init__(**kwargs)
        self.entity_name = entity_name
