# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class KeyRingResponse(Model):
    """KeyRingResponse.

    :param instance_id:
    :type instance_id: str
    :param customer_id:
    :type customer_id: str
    :param key_ring:
    :type key_ring: object
    """

    _attribute_map = {
        'instance_id': {'key': 'instanceId', 'type': 'str'},
        'customer_id': {'key': 'customerId', 'type': 'str'},
        'key_ring': {'key': 'keyRing', 'type': 'object'},
    }

    def __init__(self, **kwargs):
        super(KeyRingResponse, self).__init__(**kwargs)
        self.instance_id = kwargs.get('instance_id', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.key_ring = kwargs.get('key_ring', None)
