# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TermsOfUse(Model):
    """Represents a Terms of Use for user.

    :param state: Possible values include: 'none', 'accepted', 'declined'
    :type state: str or ~dynamics.customerinsights.api.models.enum
    :param version: Gets the current version of this document.
    :type version: str
    :param created_utc: Gets the created time of terms acceptance.
    :type created_utc: datetime
    """

    _attribute_map = {
        'state': {'key': 'state', 'type': 'str'},
        'version': {'key': 'version', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(TermsOfUse, self).__init__(**kwargs)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        self.created_utc = kwargs.get('created_utc', None)
