# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntitySearchConfiguration(Model):
    """EntitySearchConfiguration.

    :param qualified_entity_name: Gets unique entity name for this entity
    :type qualified_entity_name: str
    :param attributes: Gets the attribute search config
    :type attributes:
     list[~dynamics.customerinsights.api.models.AttributeSearchConfiguration]
    """

    _attribute_map = {
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'attributes': {'key': 'attributes', 'type': '[AttributeSearchConfiguration]'},
    }

    def __init__(self, *, qualified_entity_name: str=None, attributes=None, **kwargs) -> None:
        super(EntitySearchConfiguration, self).__init__(**kwargs)
        self.qualified_entity_name = qualified_entity_name
        self.attributes = attributes
