# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ByoPbiProvisioningInfo(Model):
    """The information for bring your own Power BI.

    :param storage_subscription_id: Storage account subscriptionId.
    :type storage_subscription_id: str
    :param storage_resource_group: Storage account Resource Group.
    :type storage_resource_group: str
    :param storage_resource_region: Storage account Region.
    :type storage_resource_region: str
    :param storage_resource_tenant_id: Storage account tenant.
    :type storage_resource_tenant_id: str
    :param capacity_id: Pbi Capacity Id.
    :type capacity_id: str
    :param synapse_serverless_sql_host_name: Synapse serverless sql host name
    :type synapse_serverless_sql_host_name: str
    """

    _attribute_map = {
        'storage_subscription_id': {'key': 'storageSubscriptionId', 'type': 'str'},
        'storage_resource_group': {'key': 'storageResourceGroup', 'type': 'str'},
        'storage_resource_region': {'key': 'storageResourceRegion', 'type': 'str'},
        'storage_resource_tenant_id': {'key': 'storageResourceTenantId', 'type': 'str'},
        'capacity_id': {'key': 'capacityId', 'type': 'str'},
        'synapse_serverless_sql_host_name': {'key': 'synapseServerlessSqlHostName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ByoPbiProvisioningInfo, self).__init__(**kwargs)
        self.storage_subscription_id = kwargs.get('storage_subscription_id', None)
        self.storage_resource_group = kwargs.get('storage_resource_group', None)
        self.storage_resource_region = kwargs.get('storage_resource_region', None)
        self.storage_resource_tenant_id = kwargs.get('storage_resource_tenant_id', None)
        self.capacity_id = kwargs.get('capacity_id', None)
        self.synapse_serverless_sql_host_name = kwargs.get('synapse_serverless_sql_host_name', None)
