# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TrialExtensionDetails(Model):
    """Extension Details of trial instance.

    :param extended_on: Gets the extended on date
    :type extended_on: datetime
    :param extended_for_days: Gets the number of days Extended
    :type extended_for_days: str
    :param extended_by: Gets the Name of Extended By
    :type extended_by: str
    """

    _attribute_map = {
        'extended_on': {'key': 'extendedOn', 'type': 'iso-8601'},
        'extended_for_days': {'key': 'extendedForDays', 'type': 'str'},
        'extended_by': {'key': 'extendedBy', 'type': 'str'},
    }

    def __init__(self, *, extended_on=None, extended_for_days: str=None, extended_by: str=None, **kwargs) -> None:
        super(TrialExtensionDetails, self).__init__(**kwargs)
        self.extended_on = extended_on
        self.extended_for_days = extended_for_days
        self.extended_by = extended_by
