# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IEdmType(Model):
    """IEdmType.

    :param type_kind: Possible values include: 'none', 'primitive', 'entity',
     'complex', 'collection', 'entityReference', 'enum', 'typeDefinition',
     'untyped', 'path'
    :type type_kind: str or ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'type_kind': {'key': 'typeKind', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(IEdmType, self).__init__(**kwargs)
        self.type_kind = kwargs.get('type_kind', None)
