# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureVariable(Model):
    """Represents a variable (computed column) in a measure.

    :param kind: Possible values include: 'arithmetic', 'date'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param name: Gets the name of the variable
    :type name: str
    :param data_type: Gets the data type of the variable
    :type data_type: str
    :param expression_text: Gets the expression text for computing the
     variable
    :type expression_text: str
    :param variable_condition_groups: Gets the variable conditions
    :type variable_condition_groups:
     list[~dynamics.customerinsights.api.models.MeasureVariableConditionGroup]
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'str'},
        'expression_text': {'key': 'expressionText', 'type': 'str'},
        'variable_condition_groups': {'key': 'variableConditionGroups', 'type': '[MeasureVariableConditionGroup]'},
    }

    def __init__(self, **kwargs):
        super(MeasureVariable, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.name = kwargs.get('name', None)
        self.data_type = kwargs.get('data_type', None)
        self.expression_text = kwargs.get('expression_text', None)
        self.variable_condition_groups = kwargs.get('variable_condition_groups', None)
