# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureVariableConditionGroup(Model):
    """Represents a set of variable conditions to apply to a MeasureVariable.

    :param name: Attribute to use in condition.
    :type name: str
    :param conditions: Gets the MeasureVariableConditions.
    :type conditions:
     list[~dynamics.customerinsights.api.models.MeasureVariableCondition]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'conditions': {'key': 'conditions', 'type': '[MeasureVariableCondition]'},
    }

    def __init__(self, **kwargs):
        super(MeasureVariableConditionGroup, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.conditions = kwargs.get('conditions', None)
