# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InsightActivityDetails(Model):
    """Collection of the Activity type and entity name corresponding to that
    activity type.

    :param activity_type: Gets the name of the activity Type.
    :type activity_type: str
    :param entity_name: Gets the name of the entity that corresponds to the
     activity type.
    :type entity_name: str
    :param activity_source_entities_info: Collection of the entity name and
     other info of the source activity entity ingested by user.
    :type activity_source_entities_info:
     list[~dynamics.customerinsights.api.models.ActivitySourceEntityInfo]
    """

    _attribute_map = {
        'activity_type': {'key': 'activityType', 'type': 'str'},
        'entity_name': {'key': 'entityName', 'type': 'str'},
        'activity_source_entities_info': {'key': 'activitySourceEntitiesInfo', 'type': '[ActivitySourceEntityInfo]'},
    }

    def __init__(self, *, activity_type: str=None, entity_name: str=None, activity_source_entities_info=None, **kwargs) -> None:
        super(InsightActivityDetails, self).__init__(**kwargs)
        self.activity_type = activity_type
        self.entity_name = entity_name
        self.activity_source_entities_info = activity_source_entities_info
