# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CreatedResult(Model):
    """CreatedResult.

    :param location:
    :type location: str
    :param value:
    :type value: object
    :param formatters:
    :type formatters: list[object]
    :param content_types:
    :type content_types: list[str]
    :param declared_type:
    :type declared_type: str
    :param status_code:
    :type status_code: int
    """

    _attribute_map = {
        'location': {'key': 'location', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
        'formatters': {'key': 'formatters', 'type': '[object]'},
        'content_types': {'key': 'contentTypes', 'type': '[str]'},
        'declared_type': {'key': 'declaredType', 'type': 'str'},
        'status_code': {'key': 'statusCode', 'type': 'int'},
    }

    def __init__(self, *, location: str=None, value=None, formatters=None, content_types=None, declared_type: str=None, status_code: int=None, **kwargs) -> None:
        super(CreatedResult, self).__init__(**kwargs)
        self.location = location
        self.value = value
        self.formatters = formatters
        self.content_types = content_types
        self.declared_type = declared_type
        self.status_code = status_code
