# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProfileStoreStateInfo(Model):
    """Represents runtime profile store state.

    :param ingestion_time: Gets the latest date of ingestion.
    :type ingestion_time: datetime
    :param primary_info:
    :type primary_info:
     ~dynamics.customerinsights.api.models.ProfileStoreCollectionInfo
    :param secondary_info:
    :type secondary_info:
     ~dynamics.customerinsights.api.models.ProfileStoreCollectionInfo
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'ingestion_time': {'key': 'ingestionTime', 'type': 'iso-8601'},
        'primary_info': {'key': 'primaryInfo', 'type': 'ProfileStoreCollectionInfo'},
        'secondary_info': {'key': 'secondaryInfo', 'type': 'ProfileStoreCollectionInfo'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, ingestion_time=None, primary_info=None, secondary_info=None, instance_id: str=None, **kwargs) -> None:
        super(ProfileStoreStateInfo, self).__init__(**kwargs)
        self.ingestion_time = ingestion_time
        self.primary_info = primary_info
        self.secondary_info = secondary_info
        self.instance_id = instance_id
