# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentRowsetStat(Model):
    """Represents a SegmentRowset Stat.

    :param rowset_id: Gets a Rowset Id for the Rowset Stat.
    :type rowset_id: str
    :param rowset_count: Gets a Rowset Count for the Rowset Id.
    :type rowset_count: long
    """

    _attribute_map = {
        'rowset_id': {'key': 'rowsetId', 'type': 'str'},
        'rowset_count': {'key': 'rowsetCount', 'type': 'long'},
    }

    def __init__(self, *, rowset_id: str=None, rowset_count: int=None, **kwargs) -> None:
        super(SegmentRowsetStat, self).__init__(**kwargs)
        self.rowset_id = rowset_id
        self.rowset_count = rowset_count
