# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntityEnrichmentInformation(Model):
    """Represents the enrichment entity info used in API requests (entity level).

    :param has_enriched_entity: Gets a value indicating whether there is an
     enriched entity for the ds entity.
    :type has_enriched_entity: bool
    :param enriched_entity_name: Name of the enriched entity.
    :type enriched_entity_name: str
    :param configured_enrichments: Gets the list configured enrichments on the
     ds entity.
    :type configured_enrichments: list[str]
    """

    _attribute_map = {
        'has_enriched_entity': {'key': 'hasEnrichedEntity', 'type': 'bool'},
        'enriched_entity_name': {'key': 'enrichedEntityName', 'type': 'str'},
        'configured_enrichments': {'key': 'configuredEnrichments', 'type': '[str]'},
    }

    def __init__(self, *, has_enriched_entity: bool=None, enriched_entity_name: str=None, configured_enrichments=None, **kwargs) -> None:
        super(EntityEnrichmentInformation, self).__init__(**kwargs)
        self.has_enriched_entity = has_enriched_entity
        self.enriched_entity_name = enriched_entity_name
        self.configured_enrichments = configured_enrichments
