# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Quantiles(Model):
    """Numerical quantiles.

    :param p0_d1: Represents 1% quantile.
    :type p0_d1: float
    :param p1: Represents 1% quantile.
    :type p1: float
    :param p5: Represents 5% quantile.
    :type p5: float
    :param p25: Represents 25% quantile.
    :type p25: float
    :param p50: Represents 50% quantile.
    :type p50: float
    :param p75: Represents 75% quantile.
    :type p75: float
    :param p95: Represents 95% quantile.
    :type p95: float
    :param p99: Represents 99% quantile.
    :type p99: float
    :param p99_d9: Represents 9% quantile.
    :type p99_d9: float
    """

    _attribute_map = {
        'p0_d1': {'key': 'p0D1', 'type': 'float'},
        'p1': {'key': 'p1', 'type': 'float'},
        'p5': {'key': 'p5', 'type': 'float'},
        'p25': {'key': 'p25', 'type': 'float'},
        'p50': {'key': 'p50', 'type': 'float'},
        'p75': {'key': 'p75', 'type': 'float'},
        'p95': {'key': 'p95', 'type': 'float'},
        'p99': {'key': 'p99', 'type': 'float'},
        'p99_d9': {'key': 'p99D9', 'type': 'float'},
    }

    def __init__(self, *, p0_d1: float=None, p1: float=None, p5: float=None, p25: float=None, p50: float=None, p75: float=None, p95: float=None, p99: float=None, p99_d9: float=None, **kwargs) -> None:
        super(Quantiles, self).__init__(**kwargs)
        self.p0_d1 = p0_d1
        self.p1 = p1
        self.p5 = p5
        self.p25 = p25
        self.p50 = p50
        self.p75 = p75
        self.p95 = p95
        self.p99 = p99
        self.p99_d9 = p99_d9
