# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchyDependency(Model):
    """Represents metadata for a Hierarchy Dependency.

    :param source_entity: Gets the source entities fully qualified name.
    :type source_entity: str
    :param account_id_attribute: Gets entity account Id.
    :type account_id_attribute: str
    :param parent_account_id_attribute: Gets parent account id.
    :type parent_account_id_attribute: str
    """

    _attribute_map = {
        'source_entity': {'key': 'sourceEntity', 'type': 'str'},
        'account_id_attribute': {'key': 'accountIdAttribute', 'type': 'str'},
        'parent_account_id_attribute': {'key': 'parentAccountIdAttribute', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(HierarchyDependency, self).__init__(**kwargs)
        self.source_entity = kwargs.get('source_entity', None)
        self.account_id_attribute = kwargs.get('account_id_attribute', None)
        self.parent_account_id_attribute = kwargs.get('parent_account_id_attribute', None)
