# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Moments(Model):
    """Statistical moments.

    :param mean: Represents the mean.
    :type mean: float
    :param standard_deviation: Represents standard deviation.
    :type standard_deviation: float
    :param variance: Represents variance.
    :type variance: float
    :param skewness: Represents skewness in data.
    :type skewness: float
    :param kurtosis: Represents kurtosis.
    :type kurtosis: float
    """

    _attribute_map = {
        'mean': {'key': 'mean', 'type': 'float'},
        'standard_deviation': {'key': 'standardDeviation', 'type': 'float'},
        'variance': {'key': 'variance', 'type': 'float'},
        'skewness': {'key': 'skewness', 'type': 'float'},
        'kurtosis': {'key': 'kurtosis', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(Moments, self).__init__(**kwargs)
        self.mean = kwargs.get('mean', None)
        self.standard_deviation = kwargs.get('standard_deviation', None)
        self.variance = kwargs.get('variance', None)
        self.skewness = kwargs.get('skewness', None)
        self.kurtosis = kwargs.get('kurtosis', None)
