# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CdsMdlInfo(Model):
    """The information on CDS MDL datalake folders.

    :param private_work_space:
    :type private_work_space:
     ~dynamics.customerinsights.api.models.DatalakeFolderDetail
    :param public_work_space:
    :type public_work_space:
     ~dynamics.customerinsights.api.models.DatalakeFolderDetail
    """

    _attribute_map = {
        'private_work_space': {'key': 'privateWorkSpace', 'type': 'DatalakeFolderDetail'},
        'public_work_space': {'key': 'publicWorkSpace', 'type': 'DatalakeFolderDetail'},
    }

    def __init__(self, **kwargs):
        super(CdsMdlInfo, self).__init__(**kwargs)
        self.private_work_space = kwargs.get('private_work_space', None)
        self.public_work_space = kwargs.get('public_work_space', None)
