# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntityDataProfile(Model):
    """Represents Entity Data Profile information.

    :param qualified_entity_name: Qualified Entity Name.
    :type qualified_entity_name: str
    :param row_count: Row count.
    :type row_count: long
    :param quarantine_row_count: Quarentine row count
    :type quarantine_row_count: long
    :param profiling_date: Date for Profiling.
    :type profiling_date: datetime
    :param profiled_attributes: Profiling attributes.
    :type profiled_attributes: str
    :param corrupt_attributes: Respresents currupt attributes.
    :type corrupt_attributes: str
    :param attribute_data_profiles: Contains all the attributes data profiles.
    :type attribute_data_profiles:
     list[~dynamics.customerinsights.api.models.AttributeDataProfile]
    """

    _attribute_map = {
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'row_count': {'key': 'rowCount', 'type': 'long'},
        'quarantine_row_count': {'key': 'quarantineRowCount', 'type': 'long'},
        'profiling_date': {'key': 'profilingDate', 'type': 'iso-8601'},
        'profiled_attributes': {'key': 'profiledAttributes', 'type': 'str'},
        'corrupt_attributes': {'key': 'corruptAttributes', 'type': 'str'},
        'attribute_data_profiles': {'key': 'attributeDataProfiles', 'type': '[AttributeDataProfile]'},
    }

    def __init__(self, *, qualified_entity_name: str=None, row_count: int=None, quarantine_row_count: int=None, profiling_date=None, profiled_attributes: str=None, corrupt_attributes: str=None, attribute_data_profiles=None, **kwargs) -> None:
        super(EntityDataProfile, self).__init__(**kwargs)
        self.qualified_entity_name = qualified_entity_name
        self.row_count = row_count
        self.quarantine_row_count = quarantine_row_count
        self.profiling_date = profiling_date
        self.profiled_attributes = profiled_attributes
        self.corrupt_attributes = corrupt_attributes
        self.attribute_data_profiles = attribute_data_profiles
