# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ODataInnerError(Model):
    """ODataInnerError.

    :param properties:
    :type properties: dict[str,
     ~dynamics.customerinsights.api.models.ODataValue]
    :param message:
    :type message: str
    :param type_name:
    :type type_name: str
    :param stack_trace:
    :type stack_trace: str
    :param inner_error:
    :type inner_error: ~dynamics.customerinsights.api.models.ODataInnerError
    """

    _attribute_map = {
        'properties': {'key': 'properties', 'type': '{ODataValue}'},
        'message': {'key': 'message', 'type': 'str'},
        'type_name': {'key': 'typeName', 'type': 'str'},
        'stack_trace': {'key': 'stackTrace', 'type': 'str'},
        'inner_error': {'key': 'innerError', 'type': 'ODataInnerError'},
    }

    def __init__(self, *, properties=None, message: str=None, type_name: str=None, stack_trace: str=None, inner_error=None, **kwargs) -> None:
        super(ODataInnerError, self).__init__(**kwargs)
        self.properties = properties
        self.message = message
        self.type_name = type_name
        self.stack_trace = stack_trace
        self.inner_error = inner_error
